Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5636)

Unified Diff: chrome/common/extensions/extension_action.h

Issue 275007: Update page action manifest parsing to match the new format. (Closed)
Patch Set: cleanup Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/extensions/extension.cc ('k') | chrome/common/extensions/extension_constants.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/extensions/extension_action.h
diff --git a/chrome/common/extensions/extension_action.h b/chrome/common/extensions/extension_action.h
index 74c22d96f760d0ef9966b42e302b8db25ecec1df..046ab636c999987a5856a8b6503dc6a622b4fb5e 100644
--- a/chrome/common/extensions/extension_action.h
+++ b/chrome/common/extensions/extension_action.h
@@ -38,8 +38,8 @@ class ExtensionAction {
extension_id_ = extension_id;
}
- std::string name() const { return name_; }
- void set_name(const std::string& name) { name_ = name; }
+ std::string title() const { return title_; }
+ void set_title(const std::string& title) { title_ = title; }
const std::vector<std::string>& icon_paths() const { return icon_paths_; }
void AddIconPath(const std::string& icon_path) {
@@ -68,8 +68,8 @@ class ExtensionAction {
// the extension manifest).
std::string extension_id_;
- // The name of the ExtensionAction.
- std::string name_;
+ // The title text of the ExtensionAction.
+ std::string title_;
// The paths to the icons that this PageIcon can show.
std::vector<std::string> icon_paths_;
@@ -116,7 +116,7 @@ class ExtensionActionState {
void set_icon(SkBitmap* icon) { icon_.reset(icon); }
private:
- // The title to use.
+ // The title text to use for tooltips and labels.
std::string title_;
// The icon to use.
« no previous file with comments | « chrome/common/extensions/extension.cc ('k') | chrome/common/extensions/extension_constants.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698